#include <cmath>
#include <fstream>
#include <iostream>

int
main( int argCount, char ** argVector )
{
    // the focal length is 100 mm
    const double focalLength = 100.0e-03;

    // the array size is 320 x 240
    const int xArraySize = 320;
    const int yArraySize = 240;

    // the pixel pitch is 40 microns
    const double pixelPitch = 40.0e-06;

    // the pixel IFOV can be computed
    const double pixelIfov = atan( pixelPitch / focalLength );

    // open the output pixel database file
    std::ofstream pixelFile( "pixels.dat" );

    // set the fixed model IDs
    int rspModelId = 0;
    int gainModelId = 0;

    // iterate through all the Y rows in this array
    for( int yy = 0; yy < yArraySize; yy++ ) {

        if( yy < ( yArraySize / 2 )) {
            gainModelId = 0;
        }
        else {
            gainModelId = 1;
        }

        // iterate through all the X pixels in this row
        for( int xx = 0; xx < xArraySize; xx++ ) {

            // compute the pixel X/Y location
            double xLoc = ( xx - ( xArraySize / 2.0 )) * pixelPitch;
            double yLoc = ( yy - ( yArraySize / 2.0 )) * pixelPitch;

            // compute the pixel X/Y angles
            double xAngle = atan( xLoc / focalLength );
            double yAngle = atan( yLoc / focalLength );

            // write this pixel out to the file
            pixelFile
                << xx << " " << yy << " "
                << xAngle << " " << yAngle << " "
                << pixelIfov << " " << pixelIfov << " "
                << rspModelId << " "
                << gainModelId << std::endl;
        }
    }
}
